@@ -44,9 +44,7 @@ class ExcelKnowledgeParser(KnowledgeParserBase):
         options = ExcelOptionsModel(**options) if isinstance(options, dict) else options
         with maybe_archive(source, mode='rb') as file:
             lines = pd.read_excel(file,
-                                  header=options.header).astype(str).fillna(value='')
-            bar.max = len(lines)
-            bar.start()
+                                  header=options.header)
             identifier_col = get_col_index(lines, options.identifier_col, 0)
             prefLabel_col = get_col_index(lines, options.preferredForm_col, identifier_col)
             altLabel_cols = get_col_index(lines, options.altForms_cols, None)
@@ -54,7 +52,10 @@ class ExcelKnowledgeParser(KnowledgeParserBase):
                         col not in [prefLabel_col, identifier_col]] \
                 if altLabel_cols \
                 else None
-            for index, row in lines.iterrows():
+            skipped_empty_lines = lines.dropna(subset=[identifier_col]).astype(str).fillna(value='')
+            bar.max = len(skipped_empty_lines)
+            bar.start()
+            for index, row in skipped_empty_lines.iterrows():
                 bar.next()
                 prefLabel = row[prefLabel_col].strip()
                 identifier = row[identifier_col].strip()
