@@ -36,6 +36,16 @@ def test_xlsx():
     check_expected(concepts)
 
 
+def test_NAF():
+    testdir = Path(__file__).parent
+    source = Path(testdir, 'data/Liste-des-codes-APE-NAF-excel-2017.xlsx')
+    parser = ExcelKnowledgeParser()
+    options = ExcelOptionsModel(encoding="utf-8", identifier_col="Id",
+                                preferredForm_col="Term")
+    concepts = list(parser.parse(source, options.dict(), Bar('Processing')))
+    assert len(concepts) == 1728
+
+
 def test_zippd_xlsx():
     testdir = Path(__file__).parent
     source = Path(testdir, 'data/lexicon.xlsx.zip')
